@@ -29,8 +29,7 @@
 #      You should have received a copy of the GNU General Public License
 #      along with pyaoi.  If not, see <https://www.gnu.org/licenses/>.
 #
-
-
+import itertools
 import operator
 from typing import (
     Callable,
@@ -40,6 +39,7 @@ from typing import (
     Iterable,
     Collection,
     Sequence,
+    MutableSequence,
 )
 
 UnaryPredicate = Callable[[Any], bool]
@@ -451,3 +451,68 @@ def copy_replace_if_not(
         A generator yielding the values of iterable with all values not satisfying unary_predicate replaced with new_val
     """
     return (new_val if not unary_predicate(val) else val for val in iterable)
+
+
+def copy_except(iterable: Iterable, exclude: Any) -> Iterable:
+    """Copy iterable while excluding all occurrences of exclude.
+
+    Args:
+        iterable: An iterable to copy
+        exclude: A value to exclude
+
+    Returns:
+        A generator yielding the values of iterable except exclude
+    """
+    return (val for val in iterable if val != exclude)
+
+
+def copy_except_if(iterable: Iterable, unary_predicate: UnaryPredicate) -> Iterable:
+    """Copy iterable while excluding all values satisfying unary_predicate.
+
+    Args:
+        iterable: An iterable to copy
+        unary_predicate: An unary predicate deciding whether to exclude a value
+
+    Returns:
+        A generator yielding the values of iterable except the ones satisfying unary_predicate
+    """
+    return (val for val in iterable if not unary_predicate(val))
+
+
+def copy_except_if_not(iterable: Iterable, unary_predicate: UnaryPredicate) -> Iterable:
+    """Copy iterable while excluding all values not satisfying unary_predicate.
+
+    Args:
+        iterable: An iterable to copy
+        unary_predicate: An unary predicate deciding whether to exclude a value
+
+    Returns:
+        A generator yielding the values of iterable except the ones not satisfying unary_predicate
+    """
+    return (val for val in iterable if unary_predicate(val))
+
+
+def fill(mutable_sequence: MutableSequence, val: Any) -> None:  # noqa: VNE002
+    """Set all indices of mutable_sequence to val.
+
+    Args:
+        mutable_sequence: A sequence to fill
+        val: A value to set all indices of sequence to
+    """
+    mutable_sequence[:] = itertools.repeat(val, len(mutable_sequence))
+
+
+def fill_n(
+    mutable_sequence: MutableSequence, val: Any, num_elements: int  # noqa: VNE002
+) -> None:
+    """Set the first num_elements indices of mutable_sequence to val.
+
+    Args:
+        mutable_sequence: A sequence to fill
+        val: A value to set indices of sequence to
+        num_elements: A value indicating how many indices(counted from the beginning) to set to val
+    """
+    mutable_sequence[:num_elements] = itertools.repeat(
+        val,
+        num_elements if num_elements < len(mutable_sequence) else len(mutable_sequence),
+    )
